## check the number of columns of a pedigree file
checkColumn <- function(pedObj)
{
  ped<-pedObj$ped
  columns<-pedObj$columns
  markerNames<-pedObj$markerNames

  ped<-as.matrix(ped)
  len <- length(columns)
  
  myncol <- ncol(ped)
  if(myncol<len+2)
    stop("Pedigree file has ", myncol, "columns.  It should have at least ", 
         columns+2, "columns.")

  names.p<-colnames(ped)

  geneInfo<-ped[,-c(1:len), drop=FALSE]
  names.g<-names.p[-c(1:len), drop=FALSE]
  if( length(geneInfo)%% 2 !=0 ) {
    stop(
         "Pedigree files should contain two columns for each markers ",
         "(one for each allele). However, the number of marker columns ",
         "for this pedigree is odd: ", length(geneInfo) 
        )
  }  

  sampleInfo<-ped[,1:len, drop=FALSE]
  if(len>6)
  {
    sampleInfo<-sampleInfo[,1:6]
    columns<-columns[1:6]
  }
  len<-ncol(sampleInfo)
  if(len<6)
    stop("`columns' contains ", len, " elements. ",   
         "It should contains exact 6 elements: ",
         "`family', `pid', `father', `mother', `sex', `affected'")

  names.s<-names.p[1:len]
  ped<-cbind(sampleInfo, geneInfo)
  colnames(ped)<-c(names.s, names.g)
  pedObj<-list(ped=ped, columns=columns, markerNames=markerNames)
  invisible(pedObj)
}

