#Basic data quality checks for markers

checkMarkers <- function(geneSetObj,
                     founderOnly=TRUE, 
                     thrsh=0.05,
                     quiet=TRUE)
{
  if(!quiet)
    cat("converting geneSet object to numerical matrix...\n")

  pedObj<-geneSet2Ped(geneSetObj)

  if(!quiet)
    cat("count allele frequencies...\n")

  res<-checkMarkers.default(pedObj, founderOnly, thrsh, quiet)   
  invisible(res)
}



checkMarkers.default<-function(pedObj, founderOnly=TRUE, thrsh=0.05, quiet=TRUE)
{
  Position<-pedObj$Position
  Name<-pedObj$markerNames

  res<-pedHardyWeinberg.default(pedObj, founderOnly=founderOnly, quiet=quiet)
  resMat<-res$resMat
  # number of observed heterozygotes
  nObsHET<-resMat[,3]
  # number of observed homozygotes
  nObsHOM<-resMat[,4]
  # number of genotypes containing missing allele
  nMissing<-resMat[,6]
  # total number of genotypes excluding genotypes containing missing alleles
  totalGeno<-nObsHET+nObsHOM
  # proportion of observed heterozygotes
  ObsHET<-nObsHET/totalGeno

  # proportion of call rate
  # i.e., percentage of non-missing genotypes for markers
  totalGeno2<-totalGeno+nMissing
  pGeno<-100*(1-nMissing/totalGeno2)

  # pvalues of HW test
  HWpval<-resMat[,9]

  # which markers pass HW test
  pos<-which(HWpval>thrsh)
  Rating<-rep(0, length(Name))
  Rating[pos]<-1 # pass HW test

  # MAF (missing allele excluded)
  res.a<-pedAFreq.default(pedObj, founderOnly=founderOnly, missingOutput=FALSE, quiet=quiet)
  # allele counts
  aPercMat<-res.a$aPercMat
  tmpfunc<-function(x)
  { 
    if(max(x)<1)
    { return(min(x[x!=0]) ) }
    else
    { return(1) }
  }
  MAF<-apply(aPercMat, 1, tmpfunc)

  # predicted heterozygosity (i.e., 2*MAF*(1-MAF))
  PredHET<-2*MAF*(1-MAF)

  dFrame<-data.frame(Name=Name, Position=Position, ObsHET=ObsHET, PredHET=PredHET, HWpval=HWpval, pGeno=pGeno, MAF=MAF, Rating=Rating)

  return(dFrame)
}

