##
## get missing genotypes frequencies 
missGFreq.default <- function(pedObj, founderOnly=TRUE)
{
  pedObj <- checkColumn(pedObj)
  ped<-pedObj$ped
  columns<-pedObj$columns
  markerNames<-pedObj$markerNames
  nMarkers<-length(markerNames)

  len <- length(columns)

  subjectNames<-paste("subject", 1:nrow(ped),sep="")
  nSubjects<-length(subjectNames)

  if(founderOnly)
  { ## get parental info
    mat1 <- ped[, c(3:4)]
    tmp <- mat1[, 1]+mat1[, 2]
    pos <- which(tmp==0)
    if(length(pos)==0)
    { stop("'founderOnly=TRUE, while the pedigree data contains no parental information!\n") }
 
    ped <- ped[pos, ] 
    subjectNames<-subjectNames[pos]
    nSubjects=length(pos)
  } 
  mat <- ped[, -c(1:len), drop=FALSE] 
  mat<-as.matrix(mat)

  ncol<-ncol(mat)

  storage.mode(mat)<-"integer"
  storage.mode(nSubjects)<-"integer"
  storage.mode(ncol)<-"integer"
  storage.mode(nMarkers)<-"integer"
  nMissSubjects<-matrix(0, nrow=nSubjects, ncol=3)
  rownames(nMissSubjects)<-subjectNames
  colnames(nMissSubjects)<-c("00", "0*", "*0")
  storage.mode(nMissSubjects)<-"integer"
  nMissMarkers<-matrix(0, nrow=nMarkers, ncol=3)
  rownames(nMissMarkers)<-markerNames
  colnames(nMissMarkers)<-c("00", "0*", "*0")
  storage.mode(nMissMarkers)<-"integer"
  
  res<-.Fortran("missgfreqdefault",
           mat, nSubjects, ncol, nMarkers,
           nMissSubjects=nMissSubjects, nMissMarkers=nMissMarkers, 
           PACKAGE="fbat")

  res<-list(nMissMarkers=res$nMissMarkers, nMissSubjects=res$nMissSubjects)
  invisible(res)
}

##
## get missing genotypes frequencies
missGFreq <- function(geneSetObj,
                     founderOnly=TRUE,
                     quiet=FALSE)
{
  if(!quiet)
    cat("converting geneSet object to numerical matrix...\n")

  pedObj<-geneSet2Ped(geneSetObj)

  if(!quiet)
    cat("counting frequencies of missing genotypes...\n")

  res<-missGFreq.default(pedObj, founderOnly)
  invisible(res)
}

