############################################

## get allele frequencies 
pedAFreq <- function(geneSetObj,
                     founderOnly=TRUE, 
                     missingOutput=FALSE,
                     quiet=FALSE)
{
  if(!quiet)
    cat("converting geneSet object to numerical matrix...\n")

  pedObj<-geneSet2Ped(geneSetObj)

  if(!quiet)
    cat("count allele frequencies...\n")

  res<-pedAFreq.default(pedObj, founderOnly, missingOutput, quiet)   
  invisible(res)
}

##
## get allele frequencies 
# missingOutput -- indicate if missing allele frequency should be output
#            'missing=TRUE' means missing allele frequency shoul be output
pedAFreq.default <- function(pedObj,
                     founderOnly=TRUE, 
                     missingOutput=FALSE,
                     quiet=FALSE)
{
  pedObj <- checkColumn(pedObj)
  ped<-pedObj$ped
  columns<-pedObj$columns
  markerNames<-pedObj$markerNames
  nMarkers<-length(markerNames)

  len <- length(columns)

  if(founderOnly==TRUE)
  { ## get parental info
    pedObj.f<-getFounders(pedObj)
    ped<-pedObj.f$ped
  } 
  mat <- ped[, -c(1:len), drop=FALSE] 

  nr <- nrow(mat) # number of subjects
  nc <- ncol(mat) # number of alleles

  ## unique alleles (might include missing allele coded as 0)
  alleles <- sort(unique(c(mat)))
  nAllele <- length(alleles)

  if(!missingOutput)
  { # only consider non-missing alleles
    alleles<-alleles[alleles!=0]
    nAllele<-length(alleles)
  }

  mat <- as.vector(t(mat))
  mat <- as.integer(mat)
  nr <- as.integer(nr)
  nMarkers <- as.integer(nMarkers)
  alleles <- as.integer(alleles)
  nAllele <- as.integer(nAllele)

  res <- .C( "getAFreq", mat, nr, nMarkers, 
            alleles, nAllele,
            aFreqMat=as.integer(rep(0, nMarkers*nAllele)),
            PACKAGE="fbat"
            )

  aFreqMat <- matrix(res$aFreqMat, nrow=nMarkers, byrow=T)
  rownames(aFreqMat) <- markerNames
  colnames(aFreqMat) <- alleles

  denom<-apply(aFreqMat, 1, sum)
  aPercMat <- aFreqMat/denom
  tmpmat <- cbind(aFreqMat, round(aPercMat, 3))

  if(!quiet)
  { cat("allele frequencies and percentages>>>\n")
    print(tmpmat)
  }

  invisible(list(aFreqMat=aFreqMat, aPercMat=aPercMat, missingOutput=missingOutput))
}
