
## get observed genotype frequencies
pedGFreq <- function(geneSetObj, founderOnly=TRUE, missingOutput=FALSE, quiet=FALSE)
{
  if(!quiet)
    cat("converting geneSet object to numerical matrix...\n")

  pedObj<-geneSet2Ped(geneSetObj)

  if(!quiet)
    cat("counting genotype frequencies...\n")
  res<-pedGFreq.default(pedObj, founderOnly, missingOutput, quiet)
}


## get observed genotype frequencies
pedGFreq.default <- function(pedObj, 
                             founderOnly=TRUE, 
                             missingOutput=FALSE,
                             quiet=FALSE)
{
  pedObj <- checkColumn(pedObj)
  ped<-pedObj$ped
  columns<-pedObj$columns
  markerNames<-pedObj$markerNames
  nMarkers<-length(markerNames)

  len <- length(columns)

  if(founderOnly==TRUE)
  { ## get parental info
    pedObj.f<-getFounders(pedObj)
    ped<-pedObj.f$ped
  } 
  mat <- ped[, -c(1:len), drop=FALSE]

  nr <- nrow(mat)
  nc <- ncol(mat)

  ## unique alleles (might include missing allele coded as 0)
  alleles <- sort(unique(c(mat)))
  nAllele <- length(alleles)

  if(!missingOutput)
  { # only consider non-missing alleles
    alleles<-alleles[alleles!=0]
    nAllele<-length(alleles)
  }

  nGenotype <- (nAllele+1)*nAllele/2

  alleles <- as.integer(alleles)
  nAllele <- as.integer(nAllele)
  genotypeNames <- rep("                                                     ", nGenotype)

  res1 <- .C("getAllGenotypes", alleles, nAllele,
             gMat=as.integer(rep(0, nGenotype*2)),
             genotypeNames=as.character(genotypeNames),
             PACKAGE="fbat"             
             )
  gMat <- res1$gMat
  genotypeNames <- res1$genotypeNames

  mat2 <- as.vector(t(mat))
  mat2 <- as.integer(mat2)
  nr <- as.integer(nr)
  nMarkers <- as.integer(nMarkers)
  nGenotype <- as.integer(nGenotype)
  gMat <- as.integer(gMat)

  res2 <- .C("getGFreq", mat2, nr, nMarkers, gMat, nGenotype, 
             countMat=as.integer(rep(0, nMarkers*nGenotype)),
             PACKAGE="fbat"
             )

  genotypeCounts <- matrix(res2$countMat, ncol=nGenotype, byrow=TRUE)

  markerNames <- getMarkerNames(ped, columns)
  colnames(genotypeCounts) <- genotypeNames
  rownames(genotypeCounts) <- markerNames

  denom<-apply(genotypeCounts, 1, sum)
  genotypePerc <- genotypeCounts/denom
  colnames(genotypePerc) <- genotypeNames
  rownames(genotypePerc) <- markerNames

  if(!quiet)
    {
      cat("genotype counts>>>\n");
      print(genotypeCounts);
    }

  invisible(list(gFreqMat=genotypeCounts, gPercMat=genotypePerc, missingOutput=missingOutput))
}

