## read HapMap CEU data
#-File formats:
#Files in all subdirs have the same format and can be concatenated 
#together if desired and used as big table, or users can download 
#just the chromosome they are interested in.  The current release 
#consists of text-table files only, with the following columns:
#
#Col1: refSNP rs# identifier at the time of release (NB might merge 
#      with another rs# in the future)
#Col2: SNP alleles according to dbSNP
#Col3: chromosome that SNP maps to 
#Col4: chromosome position of SNP, in basepairs on reference sequence
#Col5: strand of reference sequence that SNP maps to
#Col6: version of reference sequence assembly (currently NCBI build35)
#Col7: HapMap genotyping center that produced the genotypes
#Col8: LSID for HapMap protocol used for genotyping
#Col9: LSID for HapMap assay used for genotyping
#Col10: LSID for panel of individuals genotyped
#Col11: QC-code, currently 'QC+' for all entries (for future use)
#Col12 and on: observed genotypes of samples, one per column, sample
#      identifiers in column headers (Coriell catalog numbers, example:
#      NA10847). Duplicate samples have .dup suffix.
#

readHapMap <- function(
                          hapmapfile, 
                          race="CEU",
                          skip=2,
                          comment.char="&",
                          quiet=FALSE 
                          )
{
  match.arg(race, choices=c("CEU", "YRI", "CHB", "JPT"))
  # read hapmap  file
  hapmap<-read.table(hapmapfile, header=TRUE,skip=skip,
                     comment.char = comment.char)

  # get sample info
  sampleNames<-colnames(hapmap)[-c(1:11)]
  if(race=="CEU")
  { sampleInfoCEU<-NULL; rm(sampleInfoCEU); 
    data("sampleInfoCEU") 
    str(sampleInfoCEU)
    sampleInfo<-sampleInfoCEU
  } else if(race=="YRI")
  { sampleInfoYRI<-NULL; rm(sampleInfoYRI); 
    data("sampleInfoYRI") 
    str(sampleInfoCEU)
    sampleInfo<-sampleInfoYRI
  } else if(race=="CHB")
  { sampleInfoCHB<-NULL; rm(sampleInfoCHB); 
    data("sampleInfoCHB") 
    str(sampleInfoCHB)
    sampleInfo<-sampleInfoCHB
  } else 
  { sampleInfoJPT<-NULL; rm(sampleInfoJPT); 
    data("sampleInfoJPT") 
    str(sampleInfoJPT);
    sampleInfo<-sampleInfoJPT
  }

  # sampleInfo contains 6 columns, the 6th column is sampleID
  columns<-colnames(sampleInfo)[1:5]

    
  tt.sampleID<-as.character(sampleInfo[,6])
  sampleInfo2<-sampleInfo[,1:5]
  pos<-match(sampleNames, tt.sampleID)
  sampleInfo2<-sampleInfo2[pos,,drop=FALSE]

  # get marker info
  markerNames<-as.character(hapmap[,1])
  nMarkers<-length(markerNames)
  pedInfo<-t(hapmap[,-c(1:11),drop=FALSE])
  colnames(pedInfo)<-markerNames

  for(i in 1:nMarkers)
  { mat<-translate(pedInfo[,i]) 
    if(i > 1)
    { pedInfo2<-cbind(pedInfo2, mat) }
    else {
      pedInfo2<-mat
    } 
  }
  tmpnames<-rep(markerNames, rep(2, nMarkers))
  colnames(pedInfo2)<-paste(tmpnames, 1:2, sep=".")
  ped<-cbind(sampleInfo2, pedInfo2)

  Position<-rep("?", length(markerNames))
  pedObj<-list(ped=ped, columns=columns, markerNames=markerNames, Position=Position, fileName=hapmapfile)
  invisible(pedObj)
}

# translate genotype "AG" to numerical vector with two elements
translate<-function(x)
{
  n<-length(x)
  vec<-rep("N", 2*n)
  for(i in 1:n)
  { vec[i*2-1]<-substr(x[i], start=1, stop=1) 
    vec[i*2]<-substr(x[i], start=2, stop=2)
  }
  vec2<-rep(0, 2*n)
  tmpos<-which(vec=="N")
  tmpvec<-vec[-tmpos]
  u.vec<-unique(tmpvec)
  len.u<-length(u.vec)
  for(i in 1:len.u)
  { vec2[vec==u.vec[i]]<-i }

  vec2[tmpos]<-0 
  mat<-matrix(vec2, ncol=2, byrow=T)
  return(mat)

}

