\name{checkMarkers}
\alias{checkMarkers}
\alias{checkMarkers.default}
\title{Basic data quality checks for markers}
\description{
Basic data quality checks for markers.
}
\usage{
checkMarkers(geneSetObj, founderOnly=TRUE, thrsh=0.05, quiet=TRUE)
checkMarkers.default(pedObj, founderOnly=TRUE, thrsh=0.05, quiet=TRUE)
}
\arguments{
  \item{geneSetObj}{a \code{geneSet} object.}
  \item{pedObj}{a list with five elements: \code{ped}, \code{columns}, \code{markerNames}, \code{Position}, and \code{filename}. \code{ped} is a pedigree data frame whose first 6 columns are family (pedigree id), pid (patient id), father (father id), mother (mother id), sex, affected (affection status). The remaining columns are pairs of marker alleles. Each row corresponds to an individual; \code{columns} are the names of the first 5 (or 6) columns of ped file. It should be either equal to  c("family","pid","father","mother","sex","affected") or equal to c("family","pid","father","mother","sex"); \code{founderOnly} indicates if using only founder info; \code{markerNames} is a vector of marker names; \code{Position} is a vector of marker positions; \code{fileName} is the pedigree file name}
  \item{founderOnly}{indicates if using only founder info}
  \item{thrsh}{threshold for Hardy-Weinberg test. If the pvalue of the HW test for a marker is greater than \code{thrsh}, then the marker is a good marker.}
  \item{quiet}{print intermediate results if \code{quiet=FALSE}.}
}
\value{
 a data frame contains components: 
 \item{Name}{marker names.}
 \item{Position}{marker positions.}
 \item{ObsHET}{marker's observed heterozygosity (i.e., proportion of heterozygotes at markes). Missing alleles are excluded in the calculation.}
 \item{PredHET}{marker's predicted heterozygosity (i.e., \code{2*MAF*(1-MAF)}). Missing alleles are excluded in the calculation.}
 \item{HWpval}{pvalues for Hardy-Weinberg test}
 \item{pGeno}{percentage of non-missing genotypes for markes}
 \item{MAF}{minor allele frequencies. missing allele are excluded from calculation}
 \item{Rating}{\code{Rating[i]=1} means that the $i$-th marker passes HW test (do not reject H0 that HW equilibrium holds). \code{Rating[i]=0} means HW equilibrum does hold for the $i$-th marker.}
}
\author{
Weiliang Qiu \email{stwxq@channing.harvard.edu}, 
Ross Lazarus \email{ross.lazarus@channing.harvard.edu}, 
Gregory Warnes \email{warnes@bst.rochester.edu},
Nitin Jain \email{nitin.jain@pfizer.com}
}
\examples{
  data(CAMP)
  res<-checkMarkers(CAMP)
  print(res)
}
\keyword{htest}

