\name{checkMendelian}
\alias{checkMendelian}
\alias{checkMendelian.default}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ Check Mendelian Errors }
\description{
  Check Mendelian errors.
}
\usage{
checkMendelian(geneSetObj, quiet = TRUE)

checkMendelian.default(pedObj, quiet=TRUE)

}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{geneSetObj}{ a \code{geneSet} object. }
  \item{pedObj}{a list with five elements: \code{ped}, \code{columns}, \code{markerNames}, \code{Position}, and \code{filename}. \code{ped} is a pedigree data frame whose first 6 columns are family (pedigree id), pid (patient id), father (father id), mother (mother id), sex, affected (affection status). The remaining columns are pairs of marker alleles. Each row corresponds to an individual; \code{columns} are the names of the first 5 (or 6) columns of ped file. It should be either equal to  c("family","pid","father","mother","sex","affected") or equal to c("family","pid","father","mother","sex"); \code{founderOnly} indicates if using only founder info; \code{markerNames} is a vector of marker names; \code{Position} is a vector of marker positions; \code{fileName} is the pedigree file name}
  \item{quiet}{print intermediate results if \code{quiet=FALSE}.}
}
\details{
  check the following errors:
  \describe{
    \item{1}{father id = subject id}  
    \item{2}{mother id = subject id}  
    \item{3}{could not determine if an individual is a parent or a child in a family}
    \item{4}{inconsistent parental sex in a family}
    \item{5}{parental genotypes are not compatible with childrens' genotypes in a family}
    \item{6}{all childrens' genotypes are missing in a family}
    \item{7}{inconsistent sib genotypes in a family}
  }
}
\value{
A list with following elements:
  \item{errorFlag}{\code{errorFlag=1} indicates the occurence of errors; \code{errorFlag=0} indicates no error.}
  \item{compatibleFlag}{\code{compatibleFlag=0} indicates the occurence of non-compatibility; \code{compatibleFlag=1} indicates compatibility.}
  \item{nMerrMarker}{A $nMarkers x 1$ vector records the numbers of families with non-compatible genotypes, where $nMarkers$ is the number of markers.}
  \item{nMerrFamily}{A $nFamily x 1$ vector records the numbers of markers with non-compatible genotypes, where $nFamily$ is the number of families.}
  \item{nErrFamilySample}{A $nFamily x 1$ vector records the numbers of times that father id is equal to subject id or mother id is equal to subject id in a family.}
}
\author{
Weiliang Qiu \email{stwxq@channing.harvard.edu}, 
Ross Lazarus \email{ross.lazarus@channing.harvard.edu}, 
Gregory Warnes \email{warnes@bst.rochester.edu},
Nitin Jain \email{nitin.jain@pfizer.com}
}
\examples{
  data(CAMP)
  checkMendelian(CAMP, quiet = TRUE)
}
\keyword{ misc  }
